diff options
| author | Aveline Noir <jm5905938@gmail.com> | 2026-09-30 23:00:27 -0700 |
|---|---|---|
| committer | Andrew Morton <akpm@linux-foundation.org> | 2026-10-08 23:06:24 -0700 |
| commit | fda9181f6a9b0e966ae06aef4d44169dee23ca2c (patch) | |
| tree | 0ac5343853a933ddde08945ae446544d7097dca9 /tools/lib/python/kdoc | |
| parent | 620a3a95678d5fc8000a2f5fd61196de4579f942 (diff) | |
| download | linux-next-fda9181f6a9b0e966ae06aef4d44169dee23ca2c.tar.gz linux-next-fda9181f6a9b0e966ae06aef4d44169dee23ca2c.zip | |
selftests/mm: mrelease_test: fix retry limit
mrelease_test doubles the child allocation when process_mrelease() returns
ESRCH.
When size is already MAX_SIZE_MB, the current <= check still allows
another retry, causing the allocation to grow from 1024 MB to 2048 MB.
Use < instead of <= so the largest allocation attempted remains
MAX_SIZE_MB.
LLM used in discovering bug. Changes were made and reviewed manually.
Link: https://lore.kernel.org/CANOyQmFzsssM_BXHUDrV+UuVD5SZMBmSkg3UQnmw9Ns1PV7GCQ@mail.gmail.com
Fixes: 33776141b812 ("selftests: vm: add process_mrelease tests")
Signed-off-by: Aveline Noir <jm5905938@gmail.com>
Signed-off-by: Andrew Morton <akpm@linux-foundation.org>
Acked-by: David Hildenbrand (Arm) <david@kernel.org>
Acked-by: Lorenzo Stoakes (ARM) <ljs@kernel.org>
Reviewed-by: SJ Park <sj@kernel.org>
Assisted-by: LLM
Cc: Shuah Khan <shuah@kernel.org>
Cc: Suren Baghdasaryan <surenb@google.com>
Cc: Liam R. Howlett <liam@infradead.org>
Cc: Vlastimil Babka <vbabka@kernel.org>
Cc: Mike Rapoport <rppt@kernel.org>
Cc: Michal Hocko <mhocko@suse.com>
Cc: Christian Brauner <brauner@kernel.org>
Cc: Muhammad Usama Anjum <usama.anjum@arm.com>
Diffstat (limited to 'tools/lib/python/kdoc')
0 files changed, 0 insertions, 0 deletions
